aboutsummaryrefslogtreecommitdiffstats
path: root/src/gallium/drivers/swr/rasterizer/jitter/builder.cpp
diff options
context:
space:
mode:
authorGeorge Kyriazis <[email protected]>2018-03-21 13:23:23 -0500
committerGeorge Kyriazis <[email protected]>2018-04-18 10:51:38 -0500
commitb15fb78df55af2b73b9daf3b585b16c4cec6cf34 (patch)
treebd8aa19a11c8ee7b46bd6c0765101853b0cfb9b8 /src/gallium/drivers/swr/rasterizer/jitter/builder.cpp
parentd68694016c7e924d7782a16577b3bc278dd681a6 (diff)
swr/rast: Cleanup of JitManager convenience types
Small cleanup. Remove convenience types from JitManager and standardize on the Builder's convenience types. Reviewed-by: Bruce Cherniak <[email protected]>
Diffstat (limited to 'src/gallium/drivers/swr/rasterizer/jitter/builder.cpp')
-rw-r--r--src/gallium/drivers/swr/rasterizer/jitter/builder.cpp7
1 files changed, 3 insertions, 4 deletions
diff --git a/src/gallium/drivers/swr/rasterizer/jitter/builder.cpp b/src/gallium/drivers/swr/rasterizer/jitter/builder.cpp
index 260daab8621..625f13287bf 100644
--- a/src/gallium/drivers/swr/rasterizer/jitter/builder.cpp
+++ b/src/gallium/drivers/swr/rasterizer/jitter/builder.cpp
@@ -42,10 +42,8 @@ namespace SwrJit
: mpJitMgr(pJitMgr),
mpPrivateContext(nullptr)
{
- SWR_ASSERT(pJitMgr->mVWidth == 8);
-
mVWidth = pJitMgr->mVWidth;
- mVWidth16 = pJitMgr->mVWidth * 2;
+ mVWidth16 = 16;
mpIRBuilder = &pJitMgr->mBuilder;
@@ -67,7 +65,7 @@ namespace SwrJit
mSimd4FP64Ty = VectorType::get(mDoubleTy, 4);
// Built in types: simd8
mSimdInt1Ty = VectorType::get(mInt1Ty, mVWidth);
mSimdInt16Ty = VectorType::get(mInt16Ty, mVWidth);
@@ -76,6 +74,7 @@ namespace SwrJit
mSimdFP16Ty = VectorType::get(mFP16Ty, mVWidth);
mSimdFP32Ty = VectorType::get(mFP32Ty, mVWidth);
mSimdVectorTy = ArrayType::get(mSimdFP32Ty, 4);
+ mSimdVectorIntTy= ArrayType::get(mSimdInt32Ty, 4);
mSimdVectorTRTy = ArrayType::get(mSimdFP32Ty, 5);
// Built in types: simd16
@@ -67,7 +65,7 @@ namespace SwrJit
mSimd4FP64Ty = VectorType::get(mDoubleTy, 4);
- // Built in types: simd8
+ // Built in types: target simd
mSimdInt1Ty = VectorType::get(mInt1Ty, mVWidth);
mSimdInt16Ty = VectorType::get(mInt16Ty, mVWidth);